  bse__builtin_init_bsecategories_gen_proc_c,
  bse__builtin_init_bsecontainer_gen_proc_c,
  bse__builtin_init_bsedatapocket_gen_proc_c,
  bse__builtin_init_bseenums_gen_proc_c,
  bse__builtin_init_bseeditablesample_gen_proc_c,
  bse__builtin_init_bsemidinotifier_gen_proc_c,
  bse__builtin_init_bsejanitor_gen_proc_c,
  bse__builtin_init_bsepart_gen_proc_c,
  bse__builtin_init_bseparasite_gen_proc_c,
  bse__builtin_init_bseprocedure_gen_proc_c,
  bse__builtin_init_bseproject_gen_proc_c,
  bse__builtin_init_bsescripthelper_gen_proc_c,
  bse__builtin_init_bseserver_gen_proc_c,
  bse__builtin_init_bsesong_gen_proc_c,
  bse__builtin_init_bsesource_gen_proc_c,
  bse__builtin_init_bsecsynth_gen_proc_c,
  bse__builtin_init_bsesnet_gen_proc_c,
  bse__builtin_init_bsetrack_gen_proc_c,
  bse__builtin_init_bseitem_gen_proc_c,
  bse__builtin_init_bsewave_gen_proc_c,
  bse__builtin_init_bsewaveosc_gen_proc_c,
  bse__builtin_init_bsewaverepo_gen_proc_c,
